"""
The :mod:`EvoPreprocess.data_sampling` provides a way to sample datasets with evolutionary and nature inspired
algorithms.
"""

from .EvoSampling import EvoSampling

__all__ = ['EvoSampling']
